Changelog
*********

0.2.1
=====

- Minor fixes.

0.2.0
=====

- New Resource and Result classes.
- Added debug argument to Resource classes.
- New ObjectNotFound, ImproperlyConfigured and MultipleResults exceptions.

0.1.0
=====

- Initial release. Supports only JSON. Documentation and tests will come with
  future releases.
